# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vald/v1/payload/payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='vald/v1/payload/payload.proto',
  package='payload.v1',
  syntax='proto3',
  serialized_options=b'\n\035org.vdaas.vald.api.v1.payloadB\013ValdPayloadP\001Z*github.com/vdaas/vald/apis/grpc/v1/payload\310\342\036\001\320\342\036\001\340\342\036\001\300\343\036\001\310\343\036\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dvald/v1/payload/payload.proto\x12\npayload.v1\x1a\x14gogoproto/gogo.proto\x1a\x17google/rpc/status.proto\x1a\x17validate/validate.proto\"\xae\x07\n\x06Search\x1aN\n\x07Request\x12\x18\n\x06vector\x18\x01 \x03(\x02\x42\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Search.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Search.Request\x1a\x42\n\tIDRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Search.Config\x1a@\n\x0eMultiIDRequest\x12.\n\x08requests\x18\x01 \x03(\x0b\x32\x1c.payload.v1.Search.IDRequest\x1ay\n\rObjectRequest\x12\x0e\n\x06object\x18\x01 \x01(\x0c\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Search.Config\x12-\n\nvectorizer\x18\x03 \x01(\x0b\x32\x19.payload.v1.Filter.Target\x1aH\n\x12MultiObjectRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .payload.v1.Search.ObjectRequest\x1a\xcb\x01\n\x06\x43onfig\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x14\n\x03num\x18\x02 \x01(\rB\x07\xfa\x42\x04*\x02(\x01\x12\x0e\n\x06radius\x18\x03 \x01(\x02\x12\x0f\n\x07\x65psilon\x18\x04 \x01(\x02\x12\x0f\n\x07timeout\x18\x05 \x01(\x03\x12\x32\n\x0fingress_filters\x18\x06 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x12\x31\n\x0e\x65gress_filters\x18\x07 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x1aL\n\x08Response\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12,\n\x07results\x18\x02 \x03(\x0b\x32\x1b.payload.v1.Object.Distance\x1a;\n\tResponses\x12.\n\tresponses\x18\x01 \x03(\x0b\x32\x1b.payload.v1.Search.Response\x1ar\n\x0eStreamResponse\x12/\n\x08response\x18\x01 \x01(\x0b\x32\x1b.payload.v1.Search.ResponseH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\"d\n\x06\x46ilter\x1a$\n\x06Target\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x1a\x34\n\x06\x43onfig\x12*\n\x07targets\x18\x01 \x03(\x0b\x32\x19.payload.v1.Filter.Target\"\xe7\x03\n\x06Insert\x1ai\n\x07Request\x12\x33\n\x06vector\x18\x01 \x01(\x0b\x32\x19.payload.v1.Object.VectorB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Insert.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Insert.Request\x1a\x92\x01\n\rObjectRequest\x12\'\n\x06object\x18\x01 \x01(\x0b\x32\x17.payload.v1.Object.Blob\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Insert.Config\x12-\n\nvectorizer\x18\x03 \x01(\x0b\x32\x19.payload.v1.Filter.Target\x1aH\n\x12MultiObjectRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .payload.v1.Insert.ObjectRequest\x1aU\n\x06\x43onfig\x12\x1f\n\x17skip_strict_exist_check\x18\x01 \x01(\x08\x12*\n\x07\x66ilters\x18\x02 \x01(\x0b\x32\x19.payload.v1.Filter.Config\"\xe7\x03\n\x06Update\x1ai\n\x07Request\x12\x33\n\x06vector\x18\x01 \x01(\x0b\x32\x19.payload.v1.Object.VectorB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Update.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Update.Request\x1a\x92\x01\n\rObjectRequest\x12\'\n\x06object\x18\x01 \x01(\x0b\x32\x17.payload.v1.Object.Blob\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Update.Config\x12-\n\nvectorizer\x18\x03 \x01(\x0b\x32\x19.payload.v1.Filter.Target\x1aH\n\x12MultiObjectRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .payload.v1.Update.ObjectRequest\x1aU\n\x06\x43onfig\x12\x1f\n\x17skip_strict_exist_check\x18\x01 \x01(\x08\x12*\n\x07\x66ilters\x18\x02 \x01(\x0b\x32\x19.payload.v1.Filter.Config\"\xe7\x03\n\x06Upsert\x1ai\n\x07Request\x12\x33\n\x06vector\x18\x01 \x01(\x0b\x32\x19.payload.v1.Object.VectorB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Upsert.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Upsert.Request\x1a\x92\x01\n\rObjectRequest\x12\'\n\x06object\x18\x01 \x01(\x0b\x32\x17.payload.v1.Object.Blob\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Upsert.Config\x12-\n\nvectorizer\x18\x03 \x01(\x0b\x32\x19.payload.v1.Filter.Target\x1aH\n\x12MultiObjectRequest\x12\x32\n\x08requests\x18\x01 \x03(\x0b\x32 .payload.v1.Upsert.ObjectRequest\x1aU\n\x06\x43onfig\x12\x1f\n\x17skip_strict_exist_check\x18\x01 \x01(\x08\x12*\n\x07\x66ilters\x18\x02 \x01(\x0b\x32\x19.payload.v1.Filter.Config\"\xca\x01\n\x06Remove\x1aW\n\x07Request\x12!\n\x02id\x18\x01 \x01(\x0b\x32\x15.payload.v1.Object.ID\x12)\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x19.payload.v1.Remove.Config\x1a<\n\x0cMultiRequest\x12,\n\x08requests\x18\x01 \x03(\x0b\x32\x1a.payload.v1.Remove.Request\x1a)\n\x06\x43onfig\x12\x1f\n\x17skip_strict_exist_check\x18\x01 \x01(\x08\"\x98\x07\n\x06Object\x1ah\n\rVectorRequest\x12+\n\x02id\x18\x01 \x01(\x0b\x32\x15.payload.v1.Object.IDB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12*\n\x07\x66ilters\x18\x02 \x01(\x0b\x32\x19.payload.v1.Filter.Config\x1a(\n\x08\x44istance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x64istance\x18\x02 \x01(\x02\x1ar\n\x0eStreamDistance\x12/\n\x08\x64istance\x18\x01 \x01(\x0b\x32\x1b.payload.v1.Object.DistanceH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\x1a\x19\n\x02ID\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x12\n\x03IDs\x12\x0b\n\x03ids\x18\x01 \x03(\t\x1a\x37\n\x06Vector\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x06vector\x18\x02 \x03(\x02\x42\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x1a\x35\n\x07Vectors\x12*\n\x07vectors\x18\x01 \x03(\x0b\x32\x19.payload.v1.Object.Vector\x1al\n\x0cStreamVector\x12+\n\x06vector\x18\x01 \x01(\x0b\x32\x19.payload.v1.Object.VectorH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\x1a+\n\x04\x42lob\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0e\n\x06object\x18\x02 \x01(\x0c\x1a\x66\n\nStreamBlob\x12\'\n\x04\x62lob\x18\x01 \x01(\x0b\x32\x17.payload.v1.Object.BlobH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\x1a\x33\n\x08Location\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04uuid\x18\x02 \x01(\t\x12\x0b\n\x03ips\x18\x03 \x03(\t\x1ar\n\x0eStreamLocation\x12/\n\x08location\x18\x01 \x01(\x0b\x32\x1b.payload.v1.Object.LocationH\x00\x12$\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusH\x00\x42\t\n\x07payload\x1a;\n\tLocations\x12.\n\tlocations\x18\x01 \x03(\x0b\x32\x1b.payload.v1.Object.Location\"\xaf\x01\n\x04Meta\x1a\x12\n\x03Key\x12\x0b\n\x03key\x18\x01 \x01(\t\x1a\x14\n\x04Keys\x12\x0c\n\x04keys\x18\x01 \x03(\t\x1a\x12\n\x03Val\x12\x0b\n\x03val\x18\x01 \x01(\t\x1a\x14\n\x04Vals\x12\x0c\n\x04vals\x18\x01 \x03(\t\x1a\"\n\x06KeyVal\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0b\n\x03val\x18\x02 \x01(\t\x1a/\n\x07KeyVals\x12$\n\x03kvs\x18\x01 \x03(\x0b\x32\x17.payload.v1.Meta.KeyVal\";\n\x07\x43ontrol\x1a\x30\n\x12\x43reateIndexRequest\x12\x1a\n\tpool_size\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02(\x00\"\xc0\x01\n\x0bReplication\x1a\"\n\x08Recovery\x12\x16\n\x0e\x64\x65leted_agents\x18\x01 \x03(\t\x1a@\n\tRebalance\x12\x19\n\x11high_usage_agents\x18\x01 \x03(\t\x12\x18\n\x10low_usage_agents\x18\x02 \x03(\t\x1aK\n\x06\x41gents\x12\x0e\n\x06\x61gents\x18\x01 \x03(\t\x12\x16\n\x0eremoved_agents\x18\x02 \x03(\t\x12\x19\n\x11replicating_agent\x18\x03 \x03(\t\"O\n\nDiscoverer\x1a\x41\n\x07Request\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04node\x18\x03 \x01(\t\"\xcc\x04\n\x06\x42\x61\x63kup\x1aK\n\tGetVector\x1a \n\x07Request\x12\x15\n\x04uuid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\x1c\n\x05Owner\x12\x13\n\x02ip\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a-\n\tLocations\x1a \n\x07Request\x12\x15\n\x04uuid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1aS\n\x06Remove\x1a \n\x07Request\x12\x15\n\x04uuid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x1a\'\n\x0cRequestMulti\x12\x17\n\x05uuids\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1au\n\x02IP\x1a\x43\n\x08Register\x1a\x37\n\x07Request\x12\x15\n\x04uuid\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x15\n\x03ips\x18\x02 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a*\n\x06Remove\x1a \n\x07Request\x12\x15\n\x03ips\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a=\n\x06Vector\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x18\n\x06vector\x18\x03 \x03(\x02\x42\x08\xfa\x42\x05\x92\x01\x02\x08\x02\x12\x0b\n\x03ips\x18\x04 \x03(\t\x1a\x35\n\x07Vectors\x12*\n\x07vectors\x18\x01 \x03(\x0b\x32\x19.payload.v1.Backup.Vector\x1a\x83\x01\n\nCompressed\x1a\x33\n\x06Vector\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0e\n\x06vector\x18\x03 \x01(\x0c\x12\x0b\n\x03ips\x18\x04 \x03(\t\x1a@\n\x07Vectors\x12\x35\n\x07vectors\x18\x01 \x03(\x0b\x32$.payload.v1.Backup.Compressed.Vector\"\xf8\x05\n\x04Info\x1a\x87\x01\n\x05Index\x1a>\n\x05\x43ount\x12\x0e\n\x06stored\x18\x01 \x01(\r\x12\x13\n\x0buncommitted\x18\x02 \x01(\r\x12\x10\n\x08indexing\x18\x03 \x01(\x08\x1a>\n\x04UUID\x1a\x19\n\tCommitted\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x1a\x1b\n\x0bUncommitted\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x1a\xbe\x01\n\x03Pod\x12\x10\n\x08\x61pp_name\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x13\n\x02ip\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02x\x01\x12!\n\x03\x63pu\x18\x05 \x01(\x0b\x32\x14.payload.v1.Info.CPU\x12\'\n\x06memory\x18\x06 \x01(\x0b\x32\x17.payload.v1.Info.Memory\x12#\n\x04node\x18\x07 \x01(\x0b\x32\x15.payload.v1.Info.Node\x1a\xb3\x01\n\x04Node\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rinternal_addr\x18\x02 \x01(\t\x12\x15\n\rexternal_addr\x18\x03 \x01(\t\x12!\n\x03\x63pu\x18\x04 \x01(\x0b\x32\x14.payload.v1.Info.CPU\x12\'\n\x06memory\x18\x05 \x01(\x0b\x32\x17.payload.v1.Info.Memory\x12#\n\x04Pods\x18\x06 \x01(\x0b\x32\x15.payload.v1.Info.Pods\x1a\x34\n\x03\x43PU\x12\r\n\x05limit\x18\x01 \x01(\x01\x12\x0f\n\x07request\x18\x02 \x01(\x01\x12\r\n\x05usage\x18\x03 \x01(\x01\x1a\x37\n\x06Memory\x12\r\n\x05limit\x18\x01 \x01(\x01\x12\x0f\n\x07request\x18\x02 \x01(\x01\x12\r\n\x05usage\x18\x03 \x01(\x01\x1a\x34\n\x04Pods\x12,\n\x04pods\x18\x01 \x03(\x0b\x32\x14.payload.v1.Info.PodB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x37\n\x05Nodes\x12.\n\x05nodes\x18\x01 \x03(\x0b\x32\x15.payload.v1.Info.NodeB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\x11\n\x03IPs\x12\n\n\x02ip\x18\x01 \x03(\t\"\x07\n\x05\x45mptyBn\n\x1dorg.vdaas.vald.api.v1.payloadB\x0bValdPayloadP\x01Z*github.com/vdaas/vald/apis/grpc/v1/payload\xc8\xe2\x1e\x01\xd0\xe2\x1e\x01\xe0\xe2\x1e\x01\xc0\xe3\x1e\x01\xc8\xe3\x1e\x01\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_SEARCH_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Search.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.v1.Search.Request.vector', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Search.Request.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=206,
)

_SEARCH_MULTIREQUEST = _descriptor.Descriptor(
  name='MultiRequest',
  full_name='payload.v1.Search.MultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Search.MultiRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=268,
)

_SEARCH_IDREQUEST = _descriptor.Descriptor(
  name='IDRequest',
  full_name='payload.v1.Search.IDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.v1.Search.IDRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Search.IDRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=336,
)

_SEARCH_MULTIIDREQUEST = _descriptor.Descriptor(
  name='MultiIDRequest',
  full_name='payload.v1.Search.MultiIDRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Search.MultiIDRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=402,
)

_SEARCH_OBJECTREQUEST = _descriptor.Descriptor(
  name='ObjectRequest',
  full_name='payload.v1.Search.ObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='payload.v1.Search.ObjectRequest.object', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Search.ObjectRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vectorizer', full_name='payload.v1.Search.ObjectRequest.vectorizer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=525,
)

_SEARCH_MULTIOBJECTREQUEST = _descriptor.Descriptor(
  name='MultiObjectRequest',
  full_name='payload.v1.Search.MultiObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Search.MultiObjectRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=599,
)

_SEARCH_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='payload.v1.Search.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='payload.v1.Search.Config.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num', full_name='payload.v1.Search.Config.num', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='radius', full_name='payload.v1.Search.Config.radius', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epsilon', full_name='payload.v1.Search.Config.epsilon', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='payload.v1.Search.Config.timeout', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingress_filters', full_name='payload.v1.Search.Config.ingress_filters', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='egress_filters', full_name='payload.v1.Search.Config.egress_filters', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=805,
)

_SEARCH_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='payload.v1.Search.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='payload.v1.Search.Response.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='results', full_name='payload.v1.Search.Response.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=883,
)

_SEARCH_RESPONSES = _descriptor.Descriptor(
  name='Responses',
  full_name='payload.v1.Search.Responses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='payload.v1.Search.Responses.responses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=885,
  serialized_end=944,
)

_SEARCH_STREAMRESPONSE = _descriptor.Descriptor(
  name='StreamResponse',
  full_name='payload.v1.Search.StreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='payload.v1.Search.StreamResponse.response', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='payload.v1.Search.StreamResponse.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='payload.v1.Search.StreamResponse.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=946,
  serialized_end=1060,
)

_SEARCH = _descriptor.Descriptor(
  name='Search',
  full_name='payload.v1.Search',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_SEARCH_REQUEST, _SEARCH_MULTIREQUEST, _SEARCH_IDREQUEST, _SEARCH_MULTIIDREQUEST, _SEARCH_OBJECTREQUEST, _SEARCH_MULTIOBJECTREQUEST, _SEARCH_CONFIG, _SEARCH_RESPONSE, _SEARCH_RESPONSES, _SEARCH_STREAMRESPONSE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=118,
  serialized_end=1060,
)


_FILTER_TARGET = _descriptor.Descriptor(
  name='Target',
  full_name='payload.v1.Filter.Target',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='payload.v1.Filter.Target.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='payload.v1.Filter.Target.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1072,
  serialized_end=1108,
)

_FILTER_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='payload.v1.Filter.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targets', full_name='payload.v1.Filter.Config.targets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1162,
)

_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='payload.v1.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_FILTER_TARGET, _FILTER_CONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1162,
)


_INSERT_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Insert.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.v1.Insert.Request.vector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Insert.Request.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1175,
  serialized_end=1280,
)

_INSERT_MULTIREQUEST = _descriptor.Descriptor(
  name='MultiRequest',
  full_name='payload.v1.Insert.MultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Insert.MultiRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1342,
)

_INSERT_OBJECTREQUEST = _descriptor.Descriptor(
  name='ObjectRequest',
  full_name='payload.v1.Insert.ObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='payload.v1.Insert.ObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Insert.ObjectRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vectorizer', full_name='payload.v1.Insert.ObjectRequest.vectorizer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1345,
  serialized_end=1491,
)

_INSERT_MULTIOBJECTREQUEST = _descriptor.Descriptor(
  name='MultiObjectRequest',
  full_name='payload.v1.Insert.MultiObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Insert.MultiObjectRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1565,
)

_INSERT_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='payload.v1.Insert.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='skip_strict_exist_check', full_name='payload.v1.Insert.Config.skip_strict_exist_check', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='payload.v1.Insert.Config.filters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1652,
)

_INSERT = _descriptor.Descriptor(
  name='Insert',
  full_name='payload.v1.Insert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_INSERT_REQUEST, _INSERT_MULTIREQUEST, _INSERT_OBJECTREQUEST, _INSERT_MULTIOBJECTREQUEST, _INSERT_CONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1165,
  serialized_end=1652,
)


_UPDATE_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Update.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.v1.Update.Request.vector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Update.Request.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1665,
  serialized_end=1770,
)

_UPDATE_MULTIREQUEST = _descriptor.Descriptor(
  name='MultiRequest',
  full_name='payload.v1.Update.MultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Update.MultiRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1772,
  serialized_end=1832,
)

_UPDATE_OBJECTREQUEST = _descriptor.Descriptor(
  name='ObjectRequest',
  full_name='payload.v1.Update.ObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='payload.v1.Update.ObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Update.ObjectRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vectorizer', full_name='payload.v1.Update.ObjectRequest.vectorizer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1835,
  serialized_end=1981,
)

_UPDATE_MULTIOBJECTREQUEST = _descriptor.Descriptor(
  name='MultiObjectRequest',
  full_name='payload.v1.Update.MultiObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Update.MultiObjectRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1983,
  serialized_end=2055,
)

_UPDATE_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='payload.v1.Update.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='skip_strict_exist_check', full_name='payload.v1.Update.Config.skip_strict_exist_check', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='payload.v1.Update.Config.filters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1652,
)

_UPDATE = _descriptor.Descriptor(
  name='Update',
  full_name='payload.v1.Update',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_UPDATE_REQUEST, _UPDATE_MULTIREQUEST, _UPDATE_OBJECTREQUEST, _UPDATE_MULTIOBJECTREQUEST, _UPDATE_CONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=2142,
)


_UPSERT_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Upsert.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.v1.Upsert.Request.vector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Upsert.Request.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2260,
)

_UPSERT_MULTIREQUEST = _descriptor.Descriptor(
  name='MultiRequest',
  full_name='payload.v1.Upsert.MultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Upsert.MultiRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2262,
  serialized_end=2322,
)

_UPSERT_OBJECTREQUEST = _descriptor.Descriptor(
  name='ObjectRequest',
  full_name='payload.v1.Upsert.ObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object', full_name='payload.v1.Upsert.ObjectRequest.object', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Upsert.ObjectRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vectorizer', full_name='payload.v1.Upsert.ObjectRequest.vectorizer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2325,
  serialized_end=2471,
)

_UPSERT_MULTIOBJECTREQUEST = _descriptor.Descriptor(
  name='MultiObjectRequest',
  full_name='payload.v1.Upsert.MultiObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Upsert.MultiObjectRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2473,
  serialized_end=2545,
)

_UPSERT_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='payload.v1.Upsert.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='skip_strict_exist_check', full_name='payload.v1.Upsert.Config.skip_strict_exist_check', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='payload.v1.Upsert.Config.filters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1652,
)

_UPSERT = _descriptor.Descriptor(
  name='Upsert',
  full_name='payload.v1.Upsert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_UPSERT_REQUEST, _UPSERT_MULTIREQUEST, _UPSERT_OBJECTREQUEST, _UPSERT_MULTIOBJECTREQUEST, _UPSERT_CONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2145,
  serialized_end=2632,
)


_REMOVE_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Remove.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.v1.Remove.Request.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='payload.v1.Remove.Request.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2645,
  serialized_end=2732,
)

_REMOVE_MULTIREQUEST = _descriptor.Descriptor(
  name='MultiRequest',
  full_name='payload.v1.Remove.MultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='payload.v1.Remove.MultiRequest.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2734,
  serialized_end=2794,
)

_REMOVE_CONFIG = _descriptor.Descriptor(
  name='Config',
  full_name='payload.v1.Remove.Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='skip_strict_exist_check', full_name='payload.v1.Remove.Config.skip_strict_exist_check', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1567,
  serialized_end=1608,
)

_REMOVE = _descriptor.Descriptor(
  name='Remove',
  full_name='payload.v1.Remove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_REMOVE_REQUEST, _REMOVE_MULTIREQUEST, _REMOVE_CONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2635,
  serialized_end=2837,
)


_OBJECT_VECTORREQUEST = _descriptor.Descriptor(
  name='VectorRequest',
  full_name='payload.v1.Object.VectorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.v1.Object.VectorRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='payload.v1.Object.VectorRequest.filters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2850,
  serialized_end=2954,
)

_OBJECT_DISTANCE = _descriptor.Descriptor(
  name='Distance',
  full_name='payload.v1.Object.Distance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.v1.Object.Distance.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distance', full_name='payload.v1.Object.Distance.distance', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2956,
  serialized_end=2996,
)

_OBJECT_STREAMDISTANCE = _descriptor.Descriptor(
  name='StreamDistance',
  full_name='payload.v1.Object.StreamDistance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='distance', full_name='payload.v1.Object.StreamDistance.distance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='payload.v1.Object.StreamDistance.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='payload.v1.Object.StreamDistance.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2998,
  serialized_end=3112,
)

_OBJECT_ID = _descriptor.Descriptor(
  name='ID',
  full_name='payload.v1.Object.ID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.v1.Object.ID.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3114,
  serialized_end=3139,
)

_OBJECT_IDS = _descriptor.Descriptor(
  name='IDs',
  full_name='payload.v1.Object.IDs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='payload.v1.Object.IDs.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3141,
  serialized_end=3159,
)

_OBJECT_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='payload.v1.Object.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.v1.Object.Vector.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.v1.Object.Vector.vector', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3161,
  serialized_end=3216,
)

_OBJECT_VECTORS = _descriptor.Descriptor(
  name='Vectors',
  full_name='payload.v1.Object.Vectors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='payload.v1.Object.Vectors.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3218,
  serialized_end=3271,
)

_OBJECT_STREAMVECTOR = _descriptor.Descriptor(
  name='StreamVector',
  full_name='payload.v1.Object.StreamVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.v1.Object.StreamVector.vector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='payload.v1.Object.StreamVector.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='payload.v1.Object.StreamVector.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3273,
  serialized_end=3381,
)

_OBJECT_BLOB = _descriptor.Descriptor(
  name='Blob',
  full_name='payload.v1.Object.Blob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='payload.v1.Object.Blob.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object', full_name='payload.v1.Object.Blob.object', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3383,
  serialized_end=3426,
)

_OBJECT_STREAMBLOB = _descriptor.Descriptor(
  name='StreamBlob',
  full_name='payload.v1.Object.StreamBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='blob', full_name='payload.v1.Object.StreamBlob.blob', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='payload.v1.Object.StreamBlob.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='payload.v1.Object.StreamBlob.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3428,
  serialized_end=3530,
)

_OBJECT_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='payload.v1.Object.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='payload.v1.Object.Location.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Object.Location.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.v1.Object.Location.ips', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3532,
  serialized_end=3583,
)

_OBJECT_STREAMLOCATION = _descriptor.Descriptor(
  name='StreamLocation',
  full_name='payload.v1.Object.StreamLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='payload.v1.Object.StreamLocation.location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='payload.v1.Object.StreamLocation.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='payload.v1.Object.StreamLocation.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3585,
  serialized_end=3699,
)

_OBJECT_LOCATIONS = _descriptor.Descriptor(
  name='Locations',
  full_name='payload.v1.Object.Locations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='locations', full_name='payload.v1.Object.Locations.locations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3701,
  serialized_end=3760,
)

_OBJECT = _descriptor.Descriptor(
  name='Object',
  full_name='payload.v1.Object',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_OBJECT_VECTORREQUEST, _OBJECT_DISTANCE, _OBJECT_STREAMDISTANCE, _OBJECT_ID, _OBJECT_IDS, _OBJECT_VECTOR, _OBJECT_VECTORS, _OBJECT_STREAMVECTOR, _OBJECT_BLOB, _OBJECT_STREAMBLOB, _OBJECT_LOCATION, _OBJECT_STREAMLOCATION, _OBJECT_LOCATIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2840,
  serialized_end=3760,
)


_META_KEY = _descriptor.Descriptor(
  name='Key',
  full_name='payload.v1.Meta.Key',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='payload.v1.Meta.Key.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3771,
  serialized_end=3789,
)

_META_KEYS = _descriptor.Descriptor(
  name='Keys',
  full_name='payload.v1.Meta.Keys',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='keys', full_name='payload.v1.Meta.Keys.keys', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3791,
  serialized_end=3811,
)

_META_VAL = _descriptor.Descriptor(
  name='Val',
  full_name='payload.v1.Meta.Val',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='payload.v1.Meta.Val.val', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3813,
  serialized_end=3831,
)

_META_VALS = _descriptor.Descriptor(
  name='Vals',
  full_name='payload.v1.Meta.Vals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vals', full_name='payload.v1.Meta.Vals.vals', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3833,
  serialized_end=3853,
)

_META_KEYVAL = _descriptor.Descriptor(
  name='KeyVal',
  full_name='payload.v1.Meta.KeyVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='payload.v1.Meta.KeyVal.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='val', full_name='payload.v1.Meta.KeyVal.val', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3855,
  serialized_end=3889,
)

_META_KEYVALS = _descriptor.Descriptor(
  name='KeyVals',
  full_name='payload.v1.Meta.KeyVals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kvs', full_name='payload.v1.Meta.KeyVals.kvs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3891,
  serialized_end=3938,
)

_META = _descriptor.Descriptor(
  name='Meta',
  full_name='payload.v1.Meta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_META_KEY, _META_KEYS, _META_VAL, _META_VALS, _META_KEYVAL, _META_KEYVALS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3763,
  serialized_end=3938,
)


_CONTROL_CREATEINDEXREQUEST = _descriptor.Descriptor(
  name='CreateIndexRequest',
  full_name='payload.v1.Control.CreateIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pool_size', full_name='payload.v1.Control.CreateIndexRequest.pool_size', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002(\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3951,
  serialized_end=3999,
)

_CONTROL = _descriptor.Descriptor(
  name='Control',
  full_name='payload.v1.Control',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CONTROL_CREATEINDEXREQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3940,
  serialized_end=3999,
)


_REPLICATION_RECOVERY = _descriptor.Descriptor(
  name='Recovery',
  full_name='payload.v1.Replication.Recovery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deleted_agents', full_name='payload.v1.Replication.Recovery.deleted_agents', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4017,
  serialized_end=4051,
)

_REPLICATION_REBALANCE = _descriptor.Descriptor(
  name='Rebalance',
  full_name='payload.v1.Replication.Rebalance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='high_usage_agents', full_name='payload.v1.Replication.Rebalance.high_usage_agents', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_usage_agents', full_name='payload.v1.Replication.Rebalance.low_usage_agents', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4053,
  serialized_end=4117,
)

_REPLICATION_AGENTS = _descriptor.Descriptor(
  name='Agents',
  full_name='payload.v1.Replication.Agents',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='agents', full_name='payload.v1.Replication.Agents.agents', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='removed_agents', full_name='payload.v1.Replication.Agents.removed_agents', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replicating_agent', full_name='payload.v1.Replication.Agents.replicating_agent', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4119,
  serialized_end=4194,
)

_REPLICATION = _descriptor.Descriptor(
  name='Replication',
  full_name='payload.v1.Replication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_REPLICATION_RECOVERY, _REPLICATION_REBALANCE, _REPLICATION_AGENTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4002,
  serialized_end=4194,
)


_DISCOVERER_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Discoverer.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='payload.v1.Discoverer.Request.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='payload.v1.Discoverer.Request.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='payload.v1.Discoverer.Request.node', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4210,
  serialized_end=4275,
)

_DISCOVERER = _descriptor.Descriptor(
  name='Discoverer',
  full_name='payload.v1.Discoverer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_DISCOVERER_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4196,
  serialized_end=4275,
)


_BACKUP_GETVECTOR_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Backup.GetVector.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Backup.GetVector.Request.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4301,
  serialized_end=4333,
)

_BACKUP_GETVECTOR_OWNER = _descriptor.Descriptor(
  name='Owner',
  full_name='payload.v1.Backup.GetVector.Owner',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='payload.v1.Backup.GetVector.Owner.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4335,
  serialized_end=4363,
)

_BACKUP_GETVECTOR = _descriptor.Descriptor(
  name='GetVector',
  full_name='payload.v1.Backup.GetVector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_GETVECTOR_REQUEST, _BACKUP_GETVECTOR_OWNER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4288,
  serialized_end=4363,
)

_BACKUP_LOCATIONS_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Backup.Locations.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Backup.Locations.Request.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4301,
  serialized_end=4333,
)

_BACKUP_LOCATIONS = _descriptor.Descriptor(
  name='Locations',
  full_name='payload.v1.Backup.Locations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_LOCATIONS_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4365,
  serialized_end=4410,
)

_BACKUP_REMOVE_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Backup.Remove.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Backup.Remove.Request.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4301,
  serialized_end=4333,
)

_BACKUP_REMOVE_REQUESTMULTI = _descriptor.Descriptor(
  name='RequestMulti',
  full_name='payload.v1.Backup.Remove.RequestMulti',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuids', full_name='payload.v1.Backup.Remove.RequestMulti.uuids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4456,
  serialized_end=4495,
)

_BACKUP_REMOVE = _descriptor.Descriptor(
  name='Remove',
  full_name='payload.v1.Backup.Remove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_REMOVE_REQUEST, _BACKUP_REMOVE_REQUESTMULTI, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4412,
  serialized_end=4495,
)

_BACKUP_IP_REGISTER_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Backup.IP.Register.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Backup.IP.Register.Request.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.v1.Backup.IP.Register.Request.ips', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4515,
  serialized_end=4570,
)

_BACKUP_IP_REGISTER = _descriptor.Descriptor(
  name='Register',
  full_name='payload.v1.Backup.IP.Register',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_IP_REGISTER_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4503,
  serialized_end=4570,
)

_BACKUP_IP_REMOVE_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='payload.v1.Backup.IP.Remove.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.v1.Backup.IP.Remove.Request.ips', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4582,
  serialized_end=4614,
)

_BACKUP_IP_REMOVE = _descriptor.Descriptor(
  name='Remove',
  full_name='payload.v1.Backup.IP.Remove',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_IP_REMOVE_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4572,
  serialized_end=4614,
)

_BACKUP_IP = _descriptor.Descriptor(
  name='IP',
  full_name='payload.v1.Backup.IP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_IP_REGISTER, _BACKUP_IP_REMOVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4497,
  serialized_end=4614,
)

_BACKUP_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='payload.v1.Backup.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Backup.Vector.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.v1.Backup.Vector.vector', index=1,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.v1.Backup.Vector.ips', index=2,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4616,
  serialized_end=4677,
)

_BACKUP_VECTORS = _descriptor.Descriptor(
  name='Vectors',
  full_name='payload.v1.Backup.Vectors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='payload.v1.Backup.Vectors.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4679,
  serialized_end=4732,
)

_BACKUP_COMPRESSED_VECTOR = _descriptor.Descriptor(
  name='Vector',
  full_name='payload.v1.Backup.Compressed.Vector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Backup.Compressed.Vector.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='payload.v1.Backup.Compressed.Vector.vector', index=1,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ips', full_name='payload.v1.Backup.Compressed.Vector.ips', index=2,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4749,
  serialized_end=4800,
)

_BACKUP_COMPRESSED_VECTORS = _descriptor.Descriptor(
  name='Vectors',
  full_name='payload.v1.Backup.Compressed.Vectors',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectors', full_name='payload.v1.Backup.Compressed.Vectors.vectors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4802,
  serialized_end=4866,
)

_BACKUP_COMPRESSED = _descriptor.Descriptor(
  name='Compressed',
  full_name='payload.v1.Backup.Compressed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_COMPRESSED_VECTOR, _BACKUP_COMPRESSED_VECTORS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4735,
  serialized_end=4866,
)

_BACKUP = _descriptor.Descriptor(
  name='Backup',
  full_name='payload.v1.Backup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_BACKUP_GETVECTOR, _BACKUP_LOCATIONS, _BACKUP_REMOVE, _BACKUP_IP, _BACKUP_VECTOR, _BACKUP_VECTORS, _BACKUP_COMPRESSED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4278,
  serialized_end=4866,
)


_INFO_INDEX_COUNT = _descriptor.Descriptor(
  name='Count',
  full_name='payload.v1.Info.Index.Count',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stored', full_name='payload.v1.Info.Index.Count.stored', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uncommitted', full_name='payload.v1.Info.Index.Count.uncommitted', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indexing', full_name='payload.v1.Info.Index.Count.indexing', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4887,
  serialized_end=4949,
)

_INFO_INDEX_UUID_COMMITTED = _descriptor.Descriptor(
  name='Committed',
  full_name='payload.v1.Info.Index.UUID.Committed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Info.Index.UUID.Committed.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4959,
  serialized_end=4984,
)

_INFO_INDEX_UUID_UNCOMMITTED = _descriptor.Descriptor(
  name='Uncommitted',
  full_name='payload.v1.Info.Index.UUID.Uncommitted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='payload.v1.Info.Index.UUID.Uncommitted.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4986,
  serialized_end=5013,
)

_INFO_INDEX_UUID = _descriptor.Descriptor(
  name='UUID',
  full_name='payload.v1.Info.Index.UUID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_INFO_INDEX_UUID_COMMITTED, _INFO_INDEX_UUID_UNCOMMITTED, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4951,
  serialized_end=5013,
)

_INFO_INDEX = _descriptor.Descriptor(
  name='Index',
  full_name='payload.v1.Info.Index',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_INFO_INDEX_COUNT, _INFO_INDEX_UUID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4878,
  serialized_end=5013,
)

_INFO_POD = _descriptor.Descriptor(
  name='Pod',
  full_name='payload.v1.Info.Pod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_name', full_name='payload.v1.Info.Pod.app_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='payload.v1.Info.Pod.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='payload.v1.Info.Pod.namespace', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='payload.v1.Info.Pod.ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002x\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='payload.v1.Info.Pod.cpu', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory', full_name='payload.v1.Info.Pod.memory', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node', full_name='payload.v1.Info.Pod.node', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5016,
  serialized_end=5206,
)

_INFO_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='payload.v1.Info.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='payload.v1.Info.Node.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_addr', full_name='payload.v1.Info.Node.internal_addr', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_addr', full_name='payload.v1.Info.Node.external_addr', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='payload.v1.Info.Node.cpu', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memory', full_name='payload.v1.Info.Node.memory', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Pods', full_name='payload.v1.Info.Node.Pods', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5209,
  serialized_end=5388,
)

_INFO_CPU = _descriptor.Descriptor(
  name='CPU',
  full_name='payload.v1.Info.CPU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='payload.v1.Info.CPU.limit', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='payload.v1.Info.CPU.request', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='payload.v1.Info.CPU.usage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5390,
  serialized_end=5442,
)

_INFO_MEMORY = _descriptor.Descriptor(
  name='Memory',
  full_name='payload.v1.Info.Memory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='payload.v1.Info.Memory.limit', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request', full_name='payload.v1.Info.Memory.request', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='payload.v1.Info.Memory.usage', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5444,
  serialized_end=5499,
)

_INFO_PODS = _descriptor.Descriptor(
  name='Pods',
  full_name='payload.v1.Info.Pods',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pods', full_name='payload.v1.Info.Pods.pods', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5501,
  serialized_end=5553,
)

_INFO_NODES = _descriptor.Descriptor(
  name='Nodes',
  full_name='payload.v1.Info.Nodes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='payload.v1.Info.Nodes.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5555,
  serialized_end=5610,
)

_INFO_IPS = _descriptor.Descriptor(
  name='IPs',
  full_name='payload.v1.Info.IPs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='payload.v1.Info.IPs.ip', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5612,
  serialized_end=5629,
)

_INFO = _descriptor.Descriptor(
  name='Info',
  full_name='payload.v1.Info',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_INFO_INDEX, _INFO_POD, _INFO_NODE, _INFO_CPU, _INFO_MEMORY, _INFO_PODS, _INFO_NODES, _INFO_IPS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4869,
  serialized_end=5629,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='payload.v1.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5631,
  serialized_end=5638,
)

_SEARCH_REQUEST.fields_by_name['config'].message_type = _SEARCH_CONFIG
_SEARCH_REQUEST.containing_type = _SEARCH
_SEARCH_MULTIREQUEST.fields_by_name['requests'].message_type = _SEARCH_REQUEST
_SEARCH_MULTIREQUEST.containing_type = _SEARCH
_SEARCH_IDREQUEST.fields_by_name['config'].message_type = _SEARCH_CONFIG
_SEARCH_IDREQUEST.containing_type = _SEARCH
_SEARCH_MULTIIDREQUEST.fields_by_name['requests'].message_type = _SEARCH_IDREQUEST
_SEARCH_MULTIIDREQUEST.containing_type = _SEARCH
_SEARCH_OBJECTREQUEST.fields_by_name['config'].message_type = _SEARCH_CONFIG
_SEARCH_OBJECTREQUEST.fields_by_name['vectorizer'].message_type = _FILTER_TARGET
_SEARCH_OBJECTREQUEST.containing_type = _SEARCH
_SEARCH_MULTIOBJECTREQUEST.fields_by_name['requests'].message_type = _SEARCH_OBJECTREQUEST
_SEARCH_MULTIOBJECTREQUEST.containing_type = _SEARCH
_SEARCH_CONFIG.fields_by_name['ingress_filters'].message_type = _FILTER_CONFIG
_SEARCH_CONFIG.fields_by_name['egress_filters'].message_type = _FILTER_CONFIG
_SEARCH_CONFIG.containing_type = _SEARCH
_SEARCH_RESPONSE.fields_by_name['results'].message_type = _OBJECT_DISTANCE
_SEARCH_RESPONSE.containing_type = _SEARCH
_SEARCH_RESPONSES.fields_by_name['responses'].message_type = _SEARCH_RESPONSE
_SEARCH_RESPONSES.containing_type = _SEARCH
_SEARCH_STREAMRESPONSE.fields_by_name['response'].message_type = _SEARCH_RESPONSE
_SEARCH_STREAMRESPONSE.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_SEARCH_STREAMRESPONSE.containing_type = _SEARCH
_SEARCH_STREAMRESPONSE.oneofs_by_name['payload'].fields.append(
  _SEARCH_STREAMRESPONSE.fields_by_name['response'])
_SEARCH_STREAMRESPONSE.fields_by_name['response'].containing_oneof = _SEARCH_STREAMRESPONSE.oneofs_by_name['payload']
_SEARCH_STREAMRESPONSE.oneofs_by_name['payload'].fields.append(
  _SEARCH_STREAMRESPONSE.fields_by_name['status'])
_SEARCH_STREAMRESPONSE.fields_by_name['status'].containing_oneof = _SEARCH_STREAMRESPONSE.oneofs_by_name['payload']
_FILTER_TARGET.containing_type = _FILTER
_FILTER_CONFIG.fields_by_name['targets'].message_type = _FILTER_TARGET
_FILTER_CONFIG.containing_type = _FILTER
_INSERT_REQUEST.fields_by_name['vector'].message_type = _OBJECT_VECTOR
_INSERT_REQUEST.fields_by_name['config'].message_type = _INSERT_CONFIG
_INSERT_REQUEST.containing_type = _INSERT
_INSERT_MULTIREQUEST.fields_by_name['requests'].message_type = _INSERT_REQUEST
_INSERT_MULTIREQUEST.containing_type = _INSERT
_INSERT_OBJECTREQUEST.fields_by_name['object'].message_type = _OBJECT_BLOB
_INSERT_OBJECTREQUEST.fields_by_name['config'].message_type = _INSERT_CONFIG
_INSERT_OBJECTREQUEST.fields_by_name['vectorizer'].message_type = _FILTER_TARGET
_INSERT_OBJECTREQUEST.containing_type = _INSERT
_INSERT_MULTIOBJECTREQUEST.fields_by_name['requests'].message_type = _INSERT_OBJECTREQUEST
_INSERT_MULTIOBJECTREQUEST.containing_type = _INSERT
_INSERT_CONFIG.fields_by_name['filters'].message_type = _FILTER_CONFIG
_INSERT_CONFIG.containing_type = _INSERT
_UPDATE_REQUEST.fields_by_name['vector'].message_type = _OBJECT_VECTOR
_UPDATE_REQUEST.fields_by_name['config'].message_type = _UPDATE_CONFIG
_UPDATE_REQUEST.containing_type = _UPDATE
_UPDATE_MULTIREQUEST.fields_by_name['requests'].message_type = _UPDATE_REQUEST
_UPDATE_MULTIREQUEST.containing_type = _UPDATE
_UPDATE_OBJECTREQUEST.fields_by_name['object'].message_type = _OBJECT_BLOB
_UPDATE_OBJECTREQUEST.fields_by_name['config'].message_type = _UPDATE_CONFIG
_UPDATE_OBJECTREQUEST.fields_by_name['vectorizer'].message_type = _FILTER_TARGET
_UPDATE_OBJECTREQUEST.containing_type = _UPDATE
_UPDATE_MULTIOBJECTREQUEST.fields_by_name['requests'].message_type = _UPDATE_OBJECTREQUEST
_UPDATE_MULTIOBJECTREQUEST.containing_type = _UPDATE
_UPDATE_CONFIG.fields_by_name['filters'].message_type = _FILTER_CONFIG
_UPDATE_CONFIG.containing_type = _UPDATE
_UPSERT_REQUEST.fields_by_name['vector'].message_type = _OBJECT_VECTOR
_UPSERT_REQUEST.fields_by_name['config'].message_type = _UPSERT_CONFIG
_UPSERT_REQUEST.containing_type = _UPSERT
_UPSERT_MULTIREQUEST.fields_by_name['requests'].message_type = _UPSERT_REQUEST
_UPSERT_MULTIREQUEST.containing_type = _UPSERT
_UPSERT_OBJECTREQUEST.fields_by_name['object'].message_type = _OBJECT_BLOB
_UPSERT_OBJECTREQUEST.fields_by_name['config'].message_type = _UPSERT_CONFIG
_UPSERT_OBJECTREQUEST.fields_by_name['vectorizer'].message_type = _FILTER_TARGET
_UPSERT_OBJECTREQUEST.containing_type = _UPSERT
_UPSERT_MULTIOBJECTREQUEST.fields_by_name['requests'].message_type = _UPSERT_OBJECTREQUEST
_UPSERT_MULTIOBJECTREQUEST.containing_type = _UPSERT
_UPSERT_CONFIG.fields_by_name['filters'].message_type = _FILTER_CONFIG
_UPSERT_CONFIG.containing_type = _UPSERT
_REMOVE_REQUEST.fields_by_name['id'].message_type = _OBJECT_ID
_REMOVE_REQUEST.fields_by_name['config'].message_type = _REMOVE_CONFIG
_REMOVE_REQUEST.containing_type = _REMOVE
_REMOVE_MULTIREQUEST.fields_by_name['requests'].message_type = _REMOVE_REQUEST
_REMOVE_MULTIREQUEST.containing_type = _REMOVE
_REMOVE_CONFIG.containing_type = _REMOVE
_OBJECT_VECTORREQUEST.fields_by_name['id'].message_type = _OBJECT_ID
_OBJECT_VECTORREQUEST.fields_by_name['filters'].message_type = _FILTER_CONFIG
_OBJECT_VECTORREQUEST.containing_type = _OBJECT
_OBJECT_DISTANCE.containing_type = _OBJECT
_OBJECT_STREAMDISTANCE.fields_by_name['distance'].message_type = _OBJECT_DISTANCE
_OBJECT_STREAMDISTANCE.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_OBJECT_STREAMDISTANCE.containing_type = _OBJECT
_OBJECT_STREAMDISTANCE.oneofs_by_name['payload'].fields.append(
  _OBJECT_STREAMDISTANCE.fields_by_name['distance'])
_OBJECT_STREAMDISTANCE.fields_by_name['distance'].containing_oneof = _OBJECT_STREAMDISTANCE.oneofs_by_name['payload']
_OBJECT_STREAMDISTANCE.oneofs_by_name['payload'].fields.append(
  _OBJECT_STREAMDISTANCE.fields_by_name['status'])
_OBJECT_STREAMDISTANCE.fields_by_name['status'].containing_oneof = _OBJECT_STREAMDISTANCE.oneofs_by_name['payload']
_OBJECT_ID.containing_type = _OBJECT
_OBJECT_IDS.containing_type = _OBJECT
_OBJECT_VECTOR.containing_type = _OBJECT
_OBJECT_VECTORS.fields_by_name['vectors'].message_type = _OBJECT_VECTOR
_OBJECT_VECTORS.containing_type = _OBJECT
_OBJECT_STREAMVECTOR.fields_by_name['vector'].message_type = _OBJECT_VECTOR
_OBJECT_STREAMVECTOR.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_OBJECT_STREAMVECTOR.containing_type = _OBJECT
_OBJECT_STREAMVECTOR.oneofs_by_name['payload'].fields.append(
  _OBJECT_STREAMVECTOR.fields_by_name['vector'])
_OBJECT_STREAMVECTOR.fields_by_name['vector'].containing_oneof = _OBJECT_STREAMVECTOR.oneofs_by_name['payload']
_OBJECT_STREAMVECTOR.oneofs_by_name['payload'].fields.append(
  _OBJECT_STREAMVECTOR.fields_by_name['status'])
_OBJECT_STREAMVECTOR.fields_by_name['status'].containing_oneof = _OBJECT_STREAMVECTOR.oneofs_by_name['payload']
_OBJECT_BLOB.containing_type = _OBJECT
_OBJECT_STREAMBLOB.fields_by_name['blob'].message_type = _OBJECT_BLOB
_OBJECT_STREAMBLOB.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_OBJECT_STREAMBLOB.containing_type = _OBJECT
_OBJECT_STREAMBLOB.oneofs_by_name['payload'].fields.append(
  _OBJECT_STREAMBLOB.fields_by_name['blob'])
_OBJECT_STREAMBLOB.fields_by_name['blob'].containing_oneof = _OBJECT_STREAMBLOB.oneofs_by_name['payload']
_OBJECT_STREAMBLOB.oneofs_by_name['payload'].fields.append(
  _OBJECT_STREAMBLOB.fields_by_name['status'])
_OBJECT_STREAMBLOB.fields_by_name['status'].containing_oneof = _OBJECT_STREAMBLOB.oneofs_by_name['payload']
_OBJECT_LOCATION.containing_type = _OBJECT
_OBJECT_STREAMLOCATION.fields_by_name['location'].message_type = _OBJECT_LOCATION
_OBJECT_STREAMLOCATION.fields_by_name['status'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_OBJECT_STREAMLOCATION.containing_type = _OBJECT
_OBJECT_STREAMLOCATION.oneofs_by_name['payload'].fields.append(
  _OBJECT_STREAMLOCATION.fields_by_name['location'])
_OBJECT_STREAMLOCATION.fields_by_name['location'].containing_oneof = _OBJECT_STREAMLOCATION.oneofs_by_name['payload']
_OBJECT_STREAMLOCATION.oneofs_by_name['payload'].fields.append(
  _OBJECT_STREAMLOCATION.fields_by_name['status'])
_OBJECT_STREAMLOCATION.fields_by_name['status'].containing_oneof = _OBJECT_STREAMLOCATION.oneofs_by_name['payload']
_OBJECT_LOCATIONS.fields_by_name['locations'].message_type = _OBJECT_LOCATION
_OBJECT_LOCATIONS.containing_type = _OBJECT
_META_KEY.containing_type = _META
_META_KEYS.containing_type = _META
_META_VAL.containing_type = _META
_META_VALS.containing_type = _META
_META_KEYVAL.containing_type = _META
_META_KEYVALS.fields_by_name['kvs'].message_type = _META_KEYVAL
_META_KEYVALS.containing_type = _META
_CONTROL_CREATEINDEXREQUEST.containing_type = _CONTROL
_REPLICATION_RECOVERY.containing_type = _REPLICATION
_REPLICATION_REBALANCE.containing_type = _REPLICATION
_REPLICATION_AGENTS.containing_type = _REPLICATION
_DISCOVERER_REQUEST.containing_type = _DISCOVERER
_BACKUP_GETVECTOR_REQUEST.containing_type = _BACKUP_GETVECTOR
_BACKUP_GETVECTOR_OWNER.containing_type = _BACKUP_GETVECTOR
_BACKUP_GETVECTOR.containing_type = _BACKUP
_BACKUP_LOCATIONS_REQUEST.containing_type = _BACKUP_LOCATIONS
_BACKUP_LOCATIONS.containing_type = _BACKUP
_BACKUP_REMOVE_REQUEST.containing_type = _BACKUP_REMOVE
_BACKUP_REMOVE_REQUESTMULTI.containing_type = _BACKUP_REMOVE
_BACKUP_REMOVE.containing_type = _BACKUP
_BACKUP_IP_REGISTER_REQUEST.containing_type = _BACKUP_IP_REGISTER
_BACKUP_IP_REGISTER.containing_type = _BACKUP_IP
_BACKUP_IP_REMOVE_REQUEST.containing_type = _BACKUP_IP_REMOVE
_BACKUP_IP_REMOVE.containing_type = _BACKUP_IP
_BACKUP_IP.containing_type = _BACKUP
_BACKUP_VECTOR.containing_type = _BACKUP
_BACKUP_VECTORS.fields_by_name['vectors'].message_type = _BACKUP_VECTOR
_BACKUP_VECTORS.containing_type = _BACKUP
_BACKUP_COMPRESSED_VECTOR.containing_type = _BACKUP_COMPRESSED
_BACKUP_COMPRESSED_VECTORS.fields_by_name['vectors'].message_type = _BACKUP_COMPRESSED_VECTOR
_BACKUP_COMPRESSED_VECTORS.containing_type = _BACKUP_COMPRESSED
_BACKUP_COMPRESSED.containing_type = _BACKUP
_INFO_INDEX_COUNT.containing_type = _INFO_INDEX
_INFO_INDEX_UUID_COMMITTED.containing_type = _INFO_INDEX_UUID
_INFO_INDEX_UUID_UNCOMMITTED.containing_type = _INFO_INDEX_UUID
_INFO_INDEX_UUID.containing_type = _INFO_INDEX
_INFO_INDEX.containing_type = _INFO
_INFO_POD.fields_by_name['cpu'].message_type = _INFO_CPU
_INFO_POD.fields_by_name['memory'].message_type = _INFO_MEMORY
_INFO_POD.fields_by_name['node'].message_type = _INFO_NODE
_INFO_POD.containing_type = _INFO
_INFO_NODE.fields_by_name['cpu'].message_type = _INFO_CPU
_INFO_NODE.fields_by_name['memory'].message_type = _INFO_MEMORY
_INFO_NODE.fields_by_name['Pods'].message_type = _INFO_PODS
_INFO_NODE.containing_type = _INFO
_INFO_CPU.containing_type = _INFO
_INFO_MEMORY.containing_type = _INFO
_INFO_PODS.fields_by_name['pods'].message_type = _INFO_POD
_INFO_PODS.containing_type = _INFO
_INFO_NODES.fields_by_name['nodes'].message_type = _INFO_NODE
_INFO_NODES.containing_type = _INFO
_INFO_IPS.containing_type = _INFO
DESCRIPTOR.message_types_by_name['Search'] = _SEARCH
DESCRIPTOR.message_types_by_name['Filter'] = _FILTER
DESCRIPTOR.message_types_by_name['Insert'] = _INSERT
DESCRIPTOR.message_types_by_name['Update'] = _UPDATE
DESCRIPTOR.message_types_by_name['Upsert'] = _UPSERT
DESCRIPTOR.message_types_by_name['Remove'] = _REMOVE
DESCRIPTOR.message_types_by_name['Object'] = _OBJECT
DESCRIPTOR.message_types_by_name['Meta'] = _META
DESCRIPTOR.message_types_by_name['Control'] = _CONTROL
DESCRIPTOR.message_types_by_name['Replication'] = _REPLICATION
DESCRIPTOR.message_types_by_name['Discoverer'] = _DISCOVERER
DESCRIPTOR.message_types_by_name['Backup'] = _BACKUP
DESCRIPTOR.message_types_by_name['Info'] = _INFO
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Search = _reflection.GeneratedProtocolMessageType('Search', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.MultiRequest)
    })
  ,

  'IDRequest' : _reflection.GeneratedProtocolMessageType('IDRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_IDREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.IDRequest)
    })
  ,

  'MultiIDRequest' : _reflection.GeneratedProtocolMessageType('MultiIDRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_MULTIIDREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.MultiIDRequest)
    })
  ,

  'ObjectRequest' : _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_OBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.ObjectRequest)
    })
  ,

  'MultiObjectRequest' : _reflection.GeneratedProtocolMessageType('MultiObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_MULTIOBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.MultiObjectRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.Config)
    })
  ,

  'Response' : _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_RESPONSE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.Response)
    })
  ,

  'Responses' : _reflection.GeneratedProtocolMessageType('Responses', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_RESPONSES,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.Responses)
    })
  ,

  'StreamResponse' : _reflection.GeneratedProtocolMessageType('StreamResponse', (_message.Message,), {
    'DESCRIPTOR' : _SEARCH_STREAMRESPONSE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Search.StreamResponse)
    })
  ,
  'DESCRIPTOR' : _SEARCH,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Search)
  })
_sym_db.RegisterMessage(Search)
_sym_db.RegisterMessage(Search.Request)
_sym_db.RegisterMessage(Search.MultiRequest)
_sym_db.RegisterMessage(Search.IDRequest)
_sym_db.RegisterMessage(Search.MultiIDRequest)
_sym_db.RegisterMessage(Search.ObjectRequest)
_sym_db.RegisterMessage(Search.MultiObjectRequest)
_sym_db.RegisterMessage(Search.Config)
_sym_db.RegisterMessage(Search.Response)
_sym_db.RegisterMessage(Search.Responses)
_sym_db.RegisterMessage(Search.StreamResponse)

Filter = _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {

  'Target' : _reflection.GeneratedProtocolMessageType('Target', (_message.Message,), {
    'DESCRIPTOR' : _FILTER_TARGET,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Filter.Target)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _FILTER_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Filter.Config)
    })
  ,
  'DESCRIPTOR' : _FILTER,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Filter)
  })
_sym_db.RegisterMessage(Filter)
_sym_db.RegisterMessage(Filter.Target)
_sym_db.RegisterMessage(Filter.Config)

Insert = _reflection.GeneratedProtocolMessageType('Insert', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.MultiRequest)
    })
  ,

  'ObjectRequest' : _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_OBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.ObjectRequest)
    })
  ,

  'MultiObjectRequest' : _reflection.GeneratedProtocolMessageType('MultiObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_MULTIOBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.MultiObjectRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _INSERT_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Insert.Config)
    })
  ,
  'DESCRIPTOR' : _INSERT,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Insert)
  })
_sym_db.RegisterMessage(Insert)
_sym_db.RegisterMessage(Insert.Request)
_sym_db.RegisterMessage(Insert.MultiRequest)
_sym_db.RegisterMessage(Insert.ObjectRequest)
_sym_db.RegisterMessage(Insert.MultiObjectRequest)
_sym_db.RegisterMessage(Insert.Config)

Update = _reflection.GeneratedProtocolMessageType('Update', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.MultiRequest)
    })
  ,

  'ObjectRequest' : _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_OBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.ObjectRequest)
    })
  ,

  'MultiObjectRequest' : _reflection.GeneratedProtocolMessageType('MultiObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_MULTIOBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.MultiObjectRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _UPDATE_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Update.Config)
    })
  ,
  'DESCRIPTOR' : _UPDATE,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Update)
  })
_sym_db.RegisterMessage(Update)
_sym_db.RegisterMessage(Update.Request)
_sym_db.RegisterMessage(Update.MultiRequest)
_sym_db.RegisterMessage(Update.ObjectRequest)
_sym_db.RegisterMessage(Update.MultiObjectRequest)
_sym_db.RegisterMessage(Update.Config)

Upsert = _reflection.GeneratedProtocolMessageType('Upsert', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.MultiRequest)
    })
  ,

  'ObjectRequest' : _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_OBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.ObjectRequest)
    })
  ,

  'MultiObjectRequest' : _reflection.GeneratedProtocolMessageType('MultiObjectRequest', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_MULTIOBJECTREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.MultiObjectRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _UPSERT_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Upsert.Config)
    })
  ,
  'DESCRIPTOR' : _UPSERT,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Upsert)
  })
_sym_db.RegisterMessage(Upsert)
_sym_db.RegisterMessage(Upsert.Request)
_sym_db.RegisterMessage(Upsert.MultiRequest)
_sym_db.RegisterMessage(Upsert.ObjectRequest)
_sym_db.RegisterMessage(Upsert.MultiObjectRequest)
_sym_db.RegisterMessage(Upsert.Config)

Remove = _reflection.GeneratedProtocolMessageType('Remove', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _REMOVE_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Remove.Request)
    })
  ,

  'MultiRequest' : _reflection.GeneratedProtocolMessageType('MultiRequest', (_message.Message,), {
    'DESCRIPTOR' : _REMOVE_MULTIREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Remove.MultiRequest)
    })
  ,

  'Config' : _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
    'DESCRIPTOR' : _REMOVE_CONFIG,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Remove.Config)
    })
  ,
  'DESCRIPTOR' : _REMOVE,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Remove)
  })
_sym_db.RegisterMessage(Remove)
_sym_db.RegisterMessage(Remove.Request)
_sym_db.RegisterMessage(Remove.MultiRequest)
_sym_db.RegisterMessage(Remove.Config)

Object = _reflection.GeneratedProtocolMessageType('Object', (_message.Message,), {

  'VectorRequest' : _reflection.GeneratedProtocolMessageType('VectorRequest', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_VECTORREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.VectorRequest)
    })
  ,

  'Distance' : _reflection.GeneratedProtocolMessageType('Distance', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_DISTANCE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Distance)
    })
  ,

  'StreamDistance' : _reflection.GeneratedProtocolMessageType('StreamDistance', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_STREAMDISTANCE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.StreamDistance)
    })
  ,

  'ID' : _reflection.GeneratedProtocolMessageType('ID', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_ID,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.ID)
    })
  ,

  'IDs' : _reflection.GeneratedProtocolMessageType('IDs', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_IDS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.IDs)
    })
  ,

  'Vector' : _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_VECTOR,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Vector)
    })
  ,

  'Vectors' : _reflection.GeneratedProtocolMessageType('Vectors', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_VECTORS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Vectors)
    })
  ,

  'StreamVector' : _reflection.GeneratedProtocolMessageType('StreamVector', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_STREAMVECTOR,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.StreamVector)
    })
  ,

  'Blob' : _reflection.GeneratedProtocolMessageType('Blob', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_BLOB,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Blob)
    })
  ,

  'StreamBlob' : _reflection.GeneratedProtocolMessageType('StreamBlob', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_STREAMBLOB,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.StreamBlob)
    })
  ,

  'Location' : _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_LOCATION,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Location)
    })
  ,

  'StreamLocation' : _reflection.GeneratedProtocolMessageType('StreamLocation', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_STREAMLOCATION,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.StreamLocation)
    })
  ,

  'Locations' : _reflection.GeneratedProtocolMessageType('Locations', (_message.Message,), {
    'DESCRIPTOR' : _OBJECT_LOCATIONS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Object.Locations)
    })
  ,
  'DESCRIPTOR' : _OBJECT,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Object)
  })
_sym_db.RegisterMessage(Object)
_sym_db.RegisterMessage(Object.VectorRequest)
_sym_db.RegisterMessage(Object.Distance)
_sym_db.RegisterMessage(Object.StreamDistance)
_sym_db.RegisterMessage(Object.ID)
_sym_db.RegisterMessage(Object.IDs)
_sym_db.RegisterMessage(Object.Vector)
_sym_db.RegisterMessage(Object.Vectors)
_sym_db.RegisterMessage(Object.StreamVector)
_sym_db.RegisterMessage(Object.Blob)
_sym_db.RegisterMessage(Object.StreamBlob)
_sym_db.RegisterMessage(Object.Location)
_sym_db.RegisterMessage(Object.StreamLocation)
_sym_db.RegisterMessage(Object.Locations)

Meta = _reflection.GeneratedProtocolMessageType('Meta', (_message.Message,), {

  'Key' : _reflection.GeneratedProtocolMessageType('Key', (_message.Message,), {
    'DESCRIPTOR' : _META_KEY,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Meta.Key)
    })
  ,

  'Keys' : _reflection.GeneratedProtocolMessageType('Keys', (_message.Message,), {
    'DESCRIPTOR' : _META_KEYS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Meta.Keys)
    })
  ,

  'Val' : _reflection.GeneratedProtocolMessageType('Val', (_message.Message,), {
    'DESCRIPTOR' : _META_VAL,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Meta.Val)
    })
  ,

  'Vals' : _reflection.GeneratedProtocolMessageType('Vals', (_message.Message,), {
    'DESCRIPTOR' : _META_VALS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Meta.Vals)
    })
  ,

  'KeyVal' : _reflection.GeneratedProtocolMessageType('KeyVal', (_message.Message,), {
    'DESCRIPTOR' : _META_KEYVAL,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Meta.KeyVal)
    })
  ,

  'KeyVals' : _reflection.GeneratedProtocolMessageType('KeyVals', (_message.Message,), {
    'DESCRIPTOR' : _META_KEYVALS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Meta.KeyVals)
    })
  ,
  'DESCRIPTOR' : _META,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Meta)
  })
_sym_db.RegisterMessage(Meta)
_sym_db.RegisterMessage(Meta.Key)
_sym_db.RegisterMessage(Meta.Keys)
_sym_db.RegisterMessage(Meta.Val)
_sym_db.RegisterMessage(Meta.Vals)
_sym_db.RegisterMessage(Meta.KeyVal)
_sym_db.RegisterMessage(Meta.KeyVals)

Control = _reflection.GeneratedProtocolMessageType('Control', (_message.Message,), {

  'CreateIndexRequest' : _reflection.GeneratedProtocolMessageType('CreateIndexRequest', (_message.Message,), {
    'DESCRIPTOR' : _CONTROL_CREATEINDEXREQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Control.CreateIndexRequest)
    })
  ,
  'DESCRIPTOR' : _CONTROL,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Control)
  })
_sym_db.RegisterMessage(Control)
_sym_db.RegisterMessage(Control.CreateIndexRequest)

Replication = _reflection.GeneratedProtocolMessageType('Replication', (_message.Message,), {

  'Recovery' : _reflection.GeneratedProtocolMessageType('Recovery', (_message.Message,), {
    'DESCRIPTOR' : _REPLICATION_RECOVERY,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Replication.Recovery)
    })
  ,

  'Rebalance' : _reflection.GeneratedProtocolMessageType('Rebalance', (_message.Message,), {
    'DESCRIPTOR' : _REPLICATION_REBALANCE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Replication.Rebalance)
    })
  ,

  'Agents' : _reflection.GeneratedProtocolMessageType('Agents', (_message.Message,), {
    'DESCRIPTOR' : _REPLICATION_AGENTS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Replication.Agents)
    })
  ,
  'DESCRIPTOR' : _REPLICATION,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Replication)
  })
_sym_db.RegisterMessage(Replication)
_sym_db.RegisterMessage(Replication.Recovery)
_sym_db.RegisterMessage(Replication.Rebalance)
_sym_db.RegisterMessage(Replication.Agents)

Discoverer = _reflection.GeneratedProtocolMessageType('Discoverer', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
    'DESCRIPTOR' : _DISCOVERER_REQUEST,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Discoverer.Request)
    })
  ,
  'DESCRIPTOR' : _DISCOVERER,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Discoverer)
  })
_sym_db.RegisterMessage(Discoverer)
_sym_db.RegisterMessage(Discoverer.Request)

Backup = _reflection.GeneratedProtocolMessageType('Backup', (_message.Message,), {

  'GetVector' : _reflection.GeneratedProtocolMessageType('GetVector', (_message.Message,), {

    'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_GETVECTOR_REQUEST,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.GetVector.Request)
      })
    ,

    'Owner' : _reflection.GeneratedProtocolMessageType('Owner', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_GETVECTOR_OWNER,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.GetVector.Owner)
      })
    ,
    'DESCRIPTOR' : _BACKUP_GETVECTOR,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Backup.GetVector)
    })
  ,

  'Locations' : _reflection.GeneratedProtocolMessageType('Locations', (_message.Message,), {

    'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_LOCATIONS_REQUEST,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.Locations.Request)
      })
    ,
    'DESCRIPTOR' : _BACKUP_LOCATIONS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Backup.Locations)
    })
  ,

  'Remove' : _reflection.GeneratedProtocolMessageType('Remove', (_message.Message,), {

    'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_REMOVE_REQUEST,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.Remove.Request)
      })
    ,

    'RequestMulti' : _reflection.GeneratedProtocolMessageType('RequestMulti', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_REMOVE_REQUESTMULTI,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.Remove.RequestMulti)
      })
    ,
    'DESCRIPTOR' : _BACKUP_REMOVE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Backup.Remove)
    })
  ,

  'IP' : _reflection.GeneratedProtocolMessageType('IP', (_message.Message,), {

    'Register' : _reflection.GeneratedProtocolMessageType('Register', (_message.Message,), {

      'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
        'DESCRIPTOR' : _BACKUP_IP_REGISTER_REQUEST,
        '__module__' : 'vald.v1.payload.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.v1.Backup.IP.Register.Request)
        })
      ,
      'DESCRIPTOR' : _BACKUP_IP_REGISTER,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.IP.Register)
      })
    ,

    'Remove' : _reflection.GeneratedProtocolMessageType('Remove', (_message.Message,), {

      'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
        'DESCRIPTOR' : _BACKUP_IP_REMOVE_REQUEST,
        '__module__' : 'vald.v1.payload.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.v1.Backup.IP.Remove.Request)
        })
      ,
      'DESCRIPTOR' : _BACKUP_IP_REMOVE,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.IP.Remove)
      })
    ,
    'DESCRIPTOR' : _BACKUP_IP,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Backup.IP)
    })
  ,

  'Vector' : _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
    'DESCRIPTOR' : _BACKUP_VECTOR,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Backup.Vector)
    })
  ,

  'Vectors' : _reflection.GeneratedProtocolMessageType('Vectors', (_message.Message,), {
    'DESCRIPTOR' : _BACKUP_VECTORS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Backup.Vectors)
    })
  ,

  'Compressed' : _reflection.GeneratedProtocolMessageType('Compressed', (_message.Message,), {

    'Vector' : _reflection.GeneratedProtocolMessageType('Vector', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_COMPRESSED_VECTOR,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.Compressed.Vector)
      })
    ,

    'Vectors' : _reflection.GeneratedProtocolMessageType('Vectors', (_message.Message,), {
      'DESCRIPTOR' : _BACKUP_COMPRESSED_VECTORS,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Backup.Compressed.Vectors)
      })
    ,
    'DESCRIPTOR' : _BACKUP_COMPRESSED,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Backup.Compressed)
    })
  ,
  'DESCRIPTOR' : _BACKUP,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Backup)
  })
_sym_db.RegisterMessage(Backup)
_sym_db.RegisterMessage(Backup.GetVector)
_sym_db.RegisterMessage(Backup.GetVector.Request)
_sym_db.RegisterMessage(Backup.GetVector.Owner)
_sym_db.RegisterMessage(Backup.Locations)
_sym_db.RegisterMessage(Backup.Locations.Request)
_sym_db.RegisterMessage(Backup.Remove)
_sym_db.RegisterMessage(Backup.Remove.Request)
_sym_db.RegisterMessage(Backup.Remove.RequestMulti)
_sym_db.RegisterMessage(Backup.IP)
_sym_db.RegisterMessage(Backup.IP.Register)
_sym_db.RegisterMessage(Backup.IP.Register.Request)
_sym_db.RegisterMessage(Backup.IP.Remove)
_sym_db.RegisterMessage(Backup.IP.Remove.Request)
_sym_db.RegisterMessage(Backup.Vector)
_sym_db.RegisterMessage(Backup.Vectors)
_sym_db.RegisterMessage(Backup.Compressed)
_sym_db.RegisterMessage(Backup.Compressed.Vector)
_sym_db.RegisterMessage(Backup.Compressed.Vectors)

Info = _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {

  'Index' : _reflection.GeneratedProtocolMessageType('Index', (_message.Message,), {

    'Count' : _reflection.GeneratedProtocolMessageType('Count', (_message.Message,), {
      'DESCRIPTOR' : _INFO_INDEX_COUNT,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Info.Index.Count)
      })
    ,

    'UUID' : _reflection.GeneratedProtocolMessageType('UUID', (_message.Message,), {

      'Committed' : _reflection.GeneratedProtocolMessageType('Committed', (_message.Message,), {
        'DESCRIPTOR' : _INFO_INDEX_UUID_COMMITTED,
        '__module__' : 'vald.v1.payload.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.v1.Info.Index.UUID.Committed)
        })
      ,

      'Uncommitted' : _reflection.GeneratedProtocolMessageType('Uncommitted', (_message.Message,), {
        'DESCRIPTOR' : _INFO_INDEX_UUID_UNCOMMITTED,
        '__module__' : 'vald.v1.payload.payload_pb2'
        # @@protoc_insertion_point(class_scope:payload.v1.Info.Index.UUID.Uncommitted)
        })
      ,
      'DESCRIPTOR' : _INFO_INDEX_UUID,
      '__module__' : 'vald.v1.payload.payload_pb2'
      # @@protoc_insertion_point(class_scope:payload.v1.Info.Index.UUID)
      })
    ,
    'DESCRIPTOR' : _INFO_INDEX,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Index)
    })
  ,

  'Pod' : _reflection.GeneratedProtocolMessageType('Pod', (_message.Message,), {
    'DESCRIPTOR' : _INFO_POD,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Pod)
    })
  ,

  'Node' : _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
    'DESCRIPTOR' : _INFO_NODE,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Node)
    })
  ,

  'CPU' : _reflection.GeneratedProtocolMessageType('CPU', (_message.Message,), {
    'DESCRIPTOR' : _INFO_CPU,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.CPU)
    })
  ,

  'Memory' : _reflection.GeneratedProtocolMessageType('Memory', (_message.Message,), {
    'DESCRIPTOR' : _INFO_MEMORY,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Memory)
    })
  ,

  'Pods' : _reflection.GeneratedProtocolMessageType('Pods', (_message.Message,), {
    'DESCRIPTOR' : _INFO_PODS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Pods)
    })
  ,

  'Nodes' : _reflection.GeneratedProtocolMessageType('Nodes', (_message.Message,), {
    'DESCRIPTOR' : _INFO_NODES,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.Nodes)
    })
  ,

  'IPs' : _reflection.GeneratedProtocolMessageType('IPs', (_message.Message,), {
    'DESCRIPTOR' : _INFO_IPS,
    '__module__' : 'vald.v1.payload.payload_pb2'
    # @@protoc_insertion_point(class_scope:payload.v1.Info.IPs)
    })
  ,
  'DESCRIPTOR' : _INFO,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Info)
  })
_sym_db.RegisterMessage(Info)
_sym_db.RegisterMessage(Info.Index)
_sym_db.RegisterMessage(Info.Index.Count)
_sym_db.RegisterMessage(Info.Index.UUID)
_sym_db.RegisterMessage(Info.Index.UUID.Committed)
_sym_db.RegisterMessage(Info.Index.UUID.Uncommitted)
_sym_db.RegisterMessage(Info.Pod)
_sym_db.RegisterMessage(Info.Node)
_sym_db.RegisterMessage(Info.CPU)
_sym_db.RegisterMessage(Info.Memory)
_sym_db.RegisterMessage(Info.Pods)
_sym_db.RegisterMessage(Info.Nodes)
_sym_db.RegisterMessage(Info.IPs)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'vald.v1.payload.payload_pb2'
  # @@protoc_insertion_point(class_scope:payload.v1.Empty)
  })
_sym_db.RegisterMessage(Empty)


DESCRIPTOR._options = None
_SEARCH_REQUEST.fields_by_name['vector']._options = None
_SEARCH_CONFIG.fields_by_name['num']._options = None
_INSERT_REQUEST.fields_by_name['vector']._options = None
_UPDATE_REQUEST.fields_by_name['vector']._options = None
_UPSERT_REQUEST.fields_by_name['vector']._options = None
_OBJECT_VECTORREQUEST.fields_by_name['id']._options = None
_OBJECT_ID.fields_by_name['id']._options = None
_OBJECT_VECTOR.fields_by_name['id']._options = None
_OBJECT_VECTOR.fields_by_name['vector']._options = None
_OBJECT_BLOB.fields_by_name['id']._options = None
_CONTROL_CREATEINDEXREQUEST.fields_by_name['pool_size']._options = None
_DISCOVERER_REQUEST.fields_by_name['name']._options = None
_BACKUP_GETVECTOR_REQUEST.fields_by_name['uuid']._options = None
_BACKUP_GETVECTOR_OWNER.fields_by_name['ip']._options = None
_BACKUP_LOCATIONS_REQUEST.fields_by_name['uuid']._options = None
_BACKUP_REMOVE_REQUEST.fields_by_name['uuid']._options = None
_BACKUP_REMOVE_REQUESTMULTI.fields_by_name['uuids']._options = None
_BACKUP_IP_REGISTER_REQUEST.fields_by_name['uuid']._options = None
_BACKUP_IP_REGISTER_REQUEST.fields_by_name['ips']._options = None
_BACKUP_IP_REMOVE_REQUEST.fields_by_name['ips']._options = None
_BACKUP_VECTOR.fields_by_name['vector']._options = None
_INFO_POD.fields_by_name['ip']._options = None
_INFO_PODS.fields_by_name['pods']._options = None
_INFO_NODES.fields_by_name['nodes']._options = None
# @@protoc_insertion_point(module_scope)
